.container{display:flex;flex-wrap:wrap;height:calc(100vh - 50px);overflow:hidden}.box{flex:50%;box-sizing:border-box;padding:10px;height:50%;border:1px solid #ddd}.navbar[data-v-23274ff4]{background-color:#fff;overflow:hidden;height:50px}.navbar-title[data-v-23274ff4]{margin-left:10px;font-size:30px}.nav-links[data-v-23274ff4]{list-style:none;padding:0;margin:0;display:flex;justify-content:center}.nav-link[data-v-23274ff4]{display:block;color:#fff;text-align:center;padding:14px 16px;text-decoration:none;transition:background-color .3s}.nav-link[data-v-23274ff4]:hover{background-color:#ddd;color:#000}#app{font-family:Avenir,Helvetica,Arial,sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;text-align:center;color:#2c3e50}